Index: third_party/libpng/png.h |
diff --git a/third_party/libpng/png.h b/third_party/libpng/png.h |
index 29dc52b4dbea2a5c650ca08e4737bb0a2627ea79..ed9e429119dcdf102d6df48201eee04e3cdf1d4d 100644 |
--- a/third_party/libpng/png.h |
+++ b/third_party/libpng/png.h |
@@ -1,7 +1,7 @@ |
/* png.h - header file for PNG reference library |
* |
- * libpng version 1.2.45 - July 7, 2011 |
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson |
+ * libpng version 1.2.52 - November 20, 2014 |
+ * Copyright (c) 1998-2014 Glenn Randers-Pehrson |
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger) |
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.) |
* |
@@ -10,7 +10,7 @@ |
* Authors and maintainers: |
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat |
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger |
* libpng versions 0.97, January 1998, through 1.2.45 - July 7, 2011: Glenn |
* See also "Contributing Authors", below. |
* |
* Note about libpng version numbers: |
@@ -263,10 +263,35 @@ |
* 1.2.44rc01-03 13 10244 12.so.0.44[.0] |
* 1.2.44 13 10244 12.so.0.44[.0] |
* 1.2.45beta01-03 13 10245 12.so.0.45[.0] |
- * 1.0.55rc01 13 10055 10.so.0.55[.0] |
+ * 1.0.55rc01 10 10055 10.so.0.55[.0] |
* 1.2.45rc01 13 10245 12.so.0.45[.0] |
- * 1.0.55 13 10055 10.so.0.55[.0] |
+ * 1.0.55 10 10055 10.so.0.55[.0] |
* 1.2.45 13 10245 12.so.0.45[.0] |
+ * 1.2.46rc01-02 13 10246 12.so.0.46[.0] |
+ * 1.0.56 10 10056 10.so.0.56[.0] |
+ * 1.2.46 13 10246 12.so.0.46[.0] |
+ * 1.2.47beta01 13 10247 12.so.0.47[.0] |
+ * 1.2.47rc01 13 10247 12.so.0.47[.0] |
+ * 1.0.57rc01 10 10057 10.so.0.57[.0] |
+ * 1.2.47 13 10247 12.so.0.47[.0] |
+ * 1.0.57 10 10057 10.so.0.57[.0] |
+ * 1.2.48beta01 13 10248 12.so.0.48[.0] |
+ * 1.2.48rc01-02 13 10248 12.so.0.48[.0] |
+ * 1.0.58 10 10058 10.so.0.58[.0] |
+ * 1.2.48 13 10248 12.so.0.48[.0] |
+ * 1.2.49rc01 13 10249 12.so.0.49[.0] |
+ * 1.0.59 10 10059 10.so.0.59[.0] |
+ * 1.2.49 13 10249 12.so.0.49[.0] |
+ * 1.0.60 10 10060 10.so.0.60[.0] |
+ * 1.2.50 13 10250 12.so.0.50[.0] |
+ * 1.2.51beta01-05 13 10251 12.so.0.51[.0] |
+ * 1.2.51rc01-04 13 10251 12.so.0.51[.0] |
+ * 1.0.61 10 10061 10.so.0.61[.0] |
+ * 1.2.51 13 10251 12.so.0.51[.0] |
+ * 1.2.52beta01 13 10252 12.so.0.52[.0] |
+ * 1.2.52rc01-02 13 10252 12.so.0.52[.0] |
+ * 1.0.62 10 10062 10.so.0.62[.0] |
+ * 1.2.52 13 10252 12.so.0.52[.0] |
* |
* Henceforth the source version will match the shared-library major |
* and minor numbers; the shared-library major version number will be |
@@ -298,8 +323,8 @@ |
* |
* This code is released under the libpng license. |
* |
* libpng versions 1.2.6, August 15, 2004, through 1.2.45, July 7, 2011, are |
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are |
* distributed according to the same disclaimer and license as libpng-1.2.5 |
* with the following individual added to the list of Contributing Authors: |
* |
@@ -410,13 +435,13 @@ |
* Y2K compliance in libpng: |
* ========================= |
* |
- * July 7, 2011 |
+ * November 20, 2014 |
* |
* Since the PNG Development group is an ad-hoc body, we can't make |
* an official declaration. |
* |
* This is your unofficial assurance that libpng from version 0.71 and |
* upward through 1.2.45 are Y2K compliant. It is my belief that earlier |
* versions were also Y2K compliant. |
* |
* Libpng only has three year fields. One is a 2-byte unsigned integer |
@@ -472,9 +497,9 @@ |
*/ |
/* Version information for png.h - this should match the version in png.c */ |
-#define PNG_LIBPNG_VER_STRING "1.2.45" |
+#define PNG_LIBPNG_VER_STRING "1.2.52" |
#define PNG_HEADER_VERSION_STRING \ |
- " libpng version 1.2.45 - July 7, 2011\n" |
+ " libpng version 1.2.52 - November 20, 2014\n" |
#define PNG_LIBPNG_VER_SONUM 0 |
#define PNG_LIBPNG_VER_DLLNUM 13 |
@@ -482,7 +507,7 @@ |
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */ |
#define PNG_LIBPNG_VER_MAJOR 1 |
#define PNG_LIBPNG_VER_MINOR 2 |
-#define PNG_LIBPNG_VER_RELEASE 45 |
+#define PNG_LIBPNG_VER_RELEASE 52 |
/* This should match the numeric part of the final component of |
* PNG_LIBPNG_VER_STRING, omitting any leading zero: |
*/ |
@@ -512,7 +537,7 @@ |
* version 1.0.0 was mis-numbered 100 instead of 10000). From |
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release |
*/ |
-#define PNG_LIBPNG_VER 10245 /* 1.2.45 */ |
+#define PNG_LIBPNG_VER 10252 /* 1.2.52 */ |
#ifndef PNG_VERSION_INFO_ONLY |
/* Include the compression library's header */ |
@@ -1552,7 +1577,7 @@ struct png_struct_def |
/* This triggers a compiler error in png.c, if png.c and png.h |
* do not agree upon the version number. |
*/ |
-typedef png_structp version_1_2_45; |
+typedef png_structp version_1_2_52; |
typedef png_struct FAR * FAR * png_structpp; |
@@ -2639,7 +2664,7 @@ extern PNG_EXPORT(void, png_write_png) PNGARG((png_structp png_ptr, |
# define png_debug(l,m) \ |
{ \ |
int num_tabs=l; \ |
- fprintf(PNG_DEBUG_FILE,"%s"m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
+ fprintf(PNG_DEBUG_FILE,"%s" m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
(num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":"")))); \ |
} |
# endif |
@@ -2647,7 +2672,7 @@ extern PNG_EXPORT(void, png_write_png) PNGARG((png_structp png_ptr, |
# define png_debug1(l,m,p1) \ |
{ \ |
int num_tabs=l; \ |
- fprintf(PNG_DEBUG_FILE,"%s"m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
+ fprintf(PNG_DEBUG_FILE,"%s" m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
(num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":""))),p1); \ |
} |
# endif |
@@ -2655,7 +2680,7 @@ extern PNG_EXPORT(void, png_write_png) PNGARG((png_structp png_ptr, |
# define png_debug2(l,m,p1,p2) \ |
{ \ |
int num_tabs=l; \ |
- fprintf(PNG_DEBUG_FILE,"%s"m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
+ fprintf(PNG_DEBUG_FILE,"%s" m PNG_STRING_NEWLINE,(num_tabs==1 ? "\t" : \ |
(num_tabs==2 ? "\t\t":(num_tabs>2 ? "\t\t\t":""))),p1,p2); \ |
} |
# endif |
@@ -10,7 +10,7 @@ |
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat |
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger |
- * libpng versions 0.97, January 1998, through 1.2.45 - July 7, 2011: Glenn |
+ * libpng versions 0.97, January 1998, through 1.2.52 - November 20, 2014: Glenn |
* See also "Contributing Authors", below. |
* |
@@ -298,8 +323,8 @@ |
* This code is released under the libpng license. |
* |
- * libpng versions 1.2.6, August 15, 2004, through 1.2.45, July 7, 2011, are |
- * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are |
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.52, November 20, 2014, are |
+ * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are |
* distributed according to the same disclaimer and license as libpng-1.2.5 |
* with the following individual added to the list of Contributing Authors: |
@@ -410,13 +435,13 @@ |
* |
* This is your unofficial assurance that libpng from version 0.71 and |
- * upward through 1.2.45 are Y2K compliant. It is my belief that earlier |
+ * upward through 1.2.52 are Y2K compliant. It is my belief that earlier |
* versions were also Y2K compliant. |
* |